@@ -6,7 +6,7 @@ from wcd_geo_db.modules.code_seeker.query import CodeSeekSeq
 from ..query.geometry import Area
 from ..dtos import DivisionDTO, DivisionTranslationDTO
 from ..db import Division
-from ..query import DivisionsQuerySet
+from ..query import DivisionsQuerySet, SearchQueryParam
 
 
 __all__ = 'DivisionsClient',
@@ -50,7 +50,7 @@ class DivisionsClient(DBClientMixin, CodeSeekingClientMixin, NestedClient):
         codes: Optional[Sequence[Tuple[str, Any]]] = None,
         types: Optional[Sequence[str]] = None,
         location_areas: Optional[Sequence[Area]] = None,
-        search_query: Optional[str] = None,
+        search_query: Optional[SearchQueryParam] = None,
         **kw
     ) -> Sequence[int]:
         """Searches for an entities."""
@@ -77,7 +77,7 @@ class DivisionsClient(DBClientMixin, CodeSeekingClientMixin, NestedClient):
         codes: Optional[Sequence[Tuple[str, Any]]] = None,
         types: Optional[Sequence[str]] = None,
         location_areas: Optional[Sequence[Area]] = None,
-        search_query: Optional[str] = None,
+        search_query: Optional[SearchQueryParam] = None,
         **kw
     ) -> Sequence[int]:
         """Searches for a descendants of objects from `ids`."""
@@ -103,7 +103,7 @@ class DivisionsClient(DBClientMixin, CodeSeekingClientMixin, NestedClient):
         codes: Optional[Sequence[Tuple[str, Any]]] = None,
         types: Optional[Sequence[str]] = None,
         location_areas: Optional[Sequence[Area]] = None,
-        search_query: Optional[str] = None,
+        search_query: Optional[SearchQueryParam] = None,
         **kw
     ) -> Sequence[int]:
         """Searches for an ancestors of objects from `ids`."""
