@@ -1,4 +1,5 @@
 from django.db import models
+from django.contrib.postgres.indexes import GistIndex
 from django.utils.translation import pgettext_lazy
 
 from pxd_tree.hierarchy import Tree, tree_indexes
@@ -22,7 +23,18 @@ class Division(Tree, NamedMixin, SynonymizedMixin, WithGeometryMixin, CodesDefin
     class Meta:
         verbose_name = pgettext_lazy('wcd_geo_db', 'Division')
         verbose_name_plural = pgettext_lazy('wcd_geo_db', 'Divisions')
-        indexes = tree_indexes() + codes_mixin_indexes()
+        indexes = tree_indexes() + codes_mixin_indexes() + [
+            GistIndex(
+                name='%(app_label)s_%(class)s_name_idx',
+                fields=['name'],
+                opclasses=['gist_trgm_ops'],
+            ),
+            GistIndex(
+                name='%(app_label)s_%(class)s_syn_idx',
+                fields=['synonyms'],
+                opclasses=['gist_trgm_ops'],
+            ),
+        ]
 
     id = models.BigAutoField(
         primary_key=True, verbose_name=pgettext_lazy('wcd_geo_db', 'ID')
