@@ -14,10 +14,9 @@ class CodeSeekerRegistry(dict):
 
     def register(self, element: CodeSeeker) -> None:
         assert isinstance(element, CodeSeeker), 'Must be a `CodeSeeker` type.'
-        assert element not in self, (
+        assert element not in self and element.name not in self, (
             'Such a seeker already registered. \rn'
             'Remove previous manually to add new one.'
         )
 
-        self[element] = element
-
+        self[element.name] = element
