@@ -56,7 +56,8 @@ def merge_divisions(
     items: Sequence[DivisionItem],
     change_path: bool = True,
     change_level: bool = True,
-    change_types: bool = True
+    change_types: bool = True,
+    strict_types_change: bool = False,
 ):
     d = MergeCommiter(Division, update_fields=(
         ('name', 'types', 'codes', 'level', 'synonyms',)
@@ -97,7 +98,10 @@ def merge_divisions(
                 eqs.level = item['level']
 
             if change_types:
-                eqs.types = list(set((eqs.types or []) + item['types']))
+                if strict_types_change:
+                    eqs.types = list(item['types'])
+                else:
+                    eqs.types = list(set((eqs.types or []) + item['types']))
 
             inject_synonyms(eqs, item['name'])
 
