@@ -19,8 +19,14 @@ class NovaPoshtaCodeValue(TypedDict):
 class NovaPoshtaCodeSeeker(CodeSeeker):
     def Q(self, value: NovaPoshtaCodeValue, field_name: Optional[str] = None) -> models.Q:
         return models.Q(**{
-            f'{field_name or self.field_name}__{self.name}__type': value['type'],
-            f'{field_name or self.field_name}__{self.name}__ref': value['ref'],
+            f'{field_name or self.field_name}__contains': {
+                self.name: {
+                    'type': value['type'],
+                    'ref':  value['ref'],
+                }
+            }
+            # f'{field_name or self.field_name}__{self.name}__type': value['type'],
+            # f'{field_name or self.field_name}__{self.name}__ref': value['ref'],
         })
 
 
